@@ -93,11 +93,11 @@ $lang = array_merge($lang, array(
 	'ACP_AVATAR_SETTINGS_EXPLAIN'	=> 'Аватари - це невеликі унікальні зображення, які користувач може асоціювати з своєю особистістю. В залежності від стилю, вони, як правило, відображаються під іменем користувача під час перегляду тем. Тут ви можете налаштувати використання аватарів користувачами. Будь-ласка, майте на увазі, що для завантаження аватарів, вам потрібно створити директорію, яку ви вказали внизу і переконатись, що для неї встановлені права доступу на запис. Також, зауважте, що обмеження розміру файлу встановлюються лише на завантажені аватари, вони не застосовуються для віддалених зображень, на які встановлені посилання.',
 	'ALLOW_AVATARS'			=> 'Увімкнути аватари',
 	'ALLOW_AVATARS_EXPLAIN'		=> 'Дозволяє глобальне використання аватарів.<br />Якщо ви вимкнете аватари в цілому або забороните використання деяких режимів аватар, то вимкнені аватари більше не будуть відображатися на форумі, але користувачі, як і раніше, зможуть завантажувати свої власні аватари в Панелі керування.',
-  	'ALLOW_LOCAL'	=> 'Увімкнути галерею аватарів',
+   'ALLOW_LOCAL'	=> 'Увімкнути галерею аватарів',
 	'ALLOW_REMOTE'	=> 'Дозволити віддалені аватари',
 	'ALLOW_REMOTE_EXPLAIN'	=> 'Посилання на аватари з інших серверів.',
-  	'ALLOW_REMOTE_UPLOAD'			=> 'Увімкнути віддалене завантаження аватарів',
-  	'ALLOW_REMOTE_UPLOAD_EXPLAIN'	=> 'Дозволити завантаження аватарів з інших сайтів.',
+  'ALLOW_REMOTE_UPLOAD'			=> 'Увімкнути віддалене завантаження аватарів',
+  'ALLOW_REMOTE_UPLOAD_EXPLAIN'	=> 'Дозволити завантаження аватарів з інших сайтів.',
 	'ALLOW_UPLOAD'	=> 'Дозволити завантаження аватарів на сервер',
 	'AVATAR_GALLERY_PATH'	=> 'Шлях до галереї аватарів',
 	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'Шлях відносно кореневої директорії phpBB для вже завантажених зображень, наприклад <samp>images/avatars/gallery</samp>.',
@@ -105,8 +105,8 @@ $lang = array_merge($lang, array(
 	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Шлях відносно кореневої директорії phpBB, наприклад <samp>images/avatars/upload</samp>.',
 	'MAX_AVATAR_SIZE'	=> 'Максимальні розміри аватару',
 	'MAX_AVATAR_SIZE_EXPLAIN'	=> 'Ширина x Висота в пікселях.',
-	'MAX_FILESIZE'	=> 'Максимальний розмір файлу аватара',
-	'MAX_FILESIZE_EXPLAIN'	=> 'Для завантажених файлів аватарів.',
+	'MAX_FILESIZE'	=> 'Максимальний розмір файлу аватара.',
+	'MAX_FILESIZE_EXPLAIN'	=> ' Максимальний розмір кожного файлу. Якщо встановлено значення 0, максимальний розмір файлу, який може бути завантажено, обмежується лише вашою конфігурацією PHP.',
 	'MIN_AVATAR_SIZE'	=> 'Мінімальний розмір аватара',
 	'MIN_AVATAR_SIZE_EXPLAIN'	=> 'Ширина x Висота в пікселях.',
 ));
@@ -152,7 +152,7 @@ $lang = array_merge($lang, array(
 	'CHAR_LIMIT_EXPLAIN'	=> 'Кількість символів, яка дозволена в одному повідомленні/приватному повідомленні. Встановіть 0 для необмеженої кількості символів.',
 	'DELETE_TIME'		=> 'Обмеження часу на видалення',
 	'DELETE_TIME_EXPLAIN'	=> 'Обмежує час, протягом якого доступне видалення нового повідомлення. Встановлення значення 0 вимикає цю можливість.',
-  	'DISPLAY_LAST_EDITED'	=> 'Відображати інформацію про час останнього редагування',
+   'DISPLAY_LAST_EDITED'	=> 'Відображати інформацію про час останнього редагування',
 	'DISPLAY_LAST_EDITED_EXPLAIN'	=> 'Оберіть для відображення інформації про час останнього редагування в повідомленнях.',
 	'EDIT_TIME'	=> 'Обмежити час редагування',
 	'EDIT_TIME_EXPLAIN'	=> 'Обмежує час, протягом якого можна редагувати нове повідомлення. Встановлення значення 0 вимикає цю функцію.',
