@@ -86,7 +86,7 @@ $lang = array_merge($lang, array(
 	'ACP_FORUM_MANAGEMENT'	=> 'Керування форумами',
 	'ACP_FORUM_MODERATORS'	=> 'Модератори форуму',
 	'ACP_FORUM_PERMISSIONS'	=> 'Доступ до форумів',
- 	'ACP_FORUM_PERMISSIONS_COPY' => 'Копіювання прав доступу',
+   'ACP_FORUM_PERMISSIONS_COPY' => 'Копіювання прав доступу',
 	'ACP_FORUM_ROLES'	=> 'Форумні ролі',
 	'ACP_GENERAL_CONFIGURATION'	=> 'Загальні налаштування',
 	'ACP_GENERAL_TASKS'	=> 'Загальні завдання',
@@ -135,13 +135,13 @@ $lang = array_merge($lang, array(
 	'ACP_REASONS'	=> 'Причини скарг/відхилень повідомлень',
 	'ACP_REGISTER_SETTINGS'	=> 'Налаштування реєстрації',
 	'ACP_RESTORE'	=> 'Відновлення',
- 	'ACP_FEED' => 'Канали новин',
- 	'ACP_FEED_SETTINGS' => 'Налаштування каналів новин',
+   'ACP_FEED' => 'Канали новин',
+   'ACP_FEED_SETTINGS' => 'Налаштування каналів новин',
 	'ACP_SEARCH'	=> 'Конфігурація пошуку',
 	'ACP_SEARCH_INDEX'	=> 'Індексування пошуку',
 	'ACP_SEARCH_SETTINGS'	=> 'Налаштування пошуку',
 	'ACP_SECURITY_SETTINGS'	=> 'Безпека',
- 	'ACP_SEND_STATISTICS' => 'Статистика',
+   'ACP_SEND_STATISTICS' => 'Статистика',
 	'ACP_SERVER_CONFIGURATION'	=> 'Конфігурація сервера',
 	'ACP_SERVER_SETTINGS'	=> 'Налаштування сервера',
 	'ACP_SIGNATURE_SETTINGS'	=> 'Підписи',
@@ -149,7 +149,7 @@ $lang = array_merge($lang, array(
 	'ACP_STYLE_COMPONENTS'	=> 'Компоненти стилю',
 	'ACP_STYLE_MANAGEMENT'	=> 'Керування стилями',
 	'ACP_STYLES'	=> 'Стилі',
- 	'ACP_SUBMIT_CHANGES' => 'Прийняти зміни',
+   'ACP_SUBMIT_CHANGES' => 'Прийняти зміни',
 	'ACP_TEMPLATES'	=> 'Шаблони',
 	'ACP_THEMES'	=> 'Теми',
 	'ACP_UPDATE'	=> 'Оновлення',
@@ -219,8 +219,8 @@ $lang = array_merge($lang, array(
 	'LOOK_UP_FORUMS_EXPLAIN'	=> 'Ви можете обрати більше, ніж один форум.',
 	'MANAGE'	=> 'Керування',
 	'MENU_TOGGLE'	=> 'Приховати / відобразити меню зліва',
- 	'MORE' => "Докладніше", // Not used at the moment
- 	'MORE_INFORMATION' => 'Додаткові відомості',
+	'MORE' => "Докладніше", // Not used at the moment
+   'MORE_INFORMATION' => 'Додаткові відомості',
 	'MOVE_DOWN'	=> 'Вниз',
 	'MOVE_UP'	=> 'Догори',
 	'NOTIFY'	=> 'Повідомлення',
@@ -349,7 +349,7 @@ $lang = array_merge($lang, array(
 	'INACTIVE_REASON_UNKNOWN'	=> 'Невідомо',
 	'INACTIVE_USERS'	=> 'Неактивні користувачі',
 	'INACTIVE_USERS_EXPLAIN'	=> 'Це список користувачів, які зареєструвались, але їхні облікові записи неактивні. При бажанні ви можете активувати, видалити цих користувачів, або нагадати їм про необхідність активації (надіславши e-mail).',
-	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'Це список останніх 10 користувачів, які мають неактивні облікові записи. Повний список доступний з відповідного пункту меню, або за посиланням, вказаним нижче, звідки при бажанні ви зможете активувати, видалити цих користувачів, або нагадати їм про необхідність активації (надіславши e-mail).',
+	'INACTIVE_USERS_EXPLAIN_INDEX'	=> 'Це список останніх 10 користувачів, що мають неактивні облікові записи. Облікові записи неактивні тому, що в налаштуваннях реєстрації увімкнено активацію облікового запису і ці користувачі ще не активували свої облікові записи або їх було деактивовано. Повний список доступний за посиланням, вказаним нижче, звідки при бажанні ви зможете активувати, видалити цих користувачів, або нагадати їм про необхідність активації (надіславши e-mail).',
 	'NO_INACTIVE_USERS'	=> 'Немає неактивних учасників',
 	'SORT_INACTIVE'	=> 'Дата',
 	'SORT_LAST_VISIT'	=> 'датою останнього відвідування',
