@@ -192,7 +192,7 @@ $lang = array_merge($lang, array(
 	'FORM_INVALID'	=> 'Відправлена вами форма невірна. Спробуйте відправити ще раз.',
 	'FORUM'	=> 'Форум',
 	'FORUMS'	=> 'Форуми',
-	'FORUMS_MARKED'	=> 'Обрані вами форуми позначено прочитаними',
+	'FORUMS_MARKED'	=> 'Форуми позначено прочитаними.',
 	'FORUM_CAT'	=> 'Категорія',
 	'FORUM_INDEX'	=> 'Список форумів',
 	'FORUM_LINK'	=> 'Посилання на форум',
@@ -424,7 +424,7 @@ $lang = array_merge($lang, array(
 	'POSTED'	=> 'Додано',
 	'POSTED_IN_FORUM'	=> 'в',
 	'POSTED_ON_DATE'	=> 'від ',
-	'POSTS'	=> 'Повідомлення',
+	'POSTS'	=> 'Повідомлень',
 	'POSTS_UNAPPROVED'	=> 'Як мінімум одне повідомлення в цій темі не було перевірено.',
 	'POST_BY_AUTHOR'	=> '',
 	'POST_BY_FOE'	=> 'Автором цього повідомлення є <strong>%1$s</strong>, який внесений до вашого чорного списку. %2$sПоказати це повідомлення%3$s.',
@@ -439,6 +439,7 @@ $lang = array_merge($lang, array(
 	'POST_SUBJECT'	=> 'Тема повідомлення',
 	'POST_TIME'	=> 'Час розміщення',
 	'POST_UNAPPROVED'	=> 'Це повідомлення очікує на перевірку',
+  'POWERED_BY'			=> 'Працює на %s',
 	'PREVIEW'	=> 'Попередній перегляд',
 	'PREVIOUS'	=> 'Поперед.',
 	'PRIVACY'	=> 'Заява про конфіденційність',
@@ -446,6 +447,7 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGES'	=> 'Приватні повідомлення',
 	'PRIVATE_MESSAGING'	=> 'Приватні повідомлення',
 	'PROFILE'	=> 'Панель керування',
+  'RANK'						=> 'Звання',
 	'READING_FORUM'	=> 'Переглядає повідомлення в %s',
 	'READING_GLOBAL_ANNOUNCE'	=> 'Читає загальне оголошення',
 	'READING_TOPIC'	=> 'Переглядає тему в %s',
@@ -593,7 +595,7 @@ $lang = array_merge($lang, array(
 	'TOO_SHORT_WEBSITE'	=> 'Введена вами адреса вебсайту надто коротка.',
 	'TOO_SHORT_YIM'	=> 'Введене вами ім\'я Yahoo Messenger надто коротке.',
 	'TOPIC'	=> 'Тема',
-	'TOPICS'	=> 'Теми',
+	'TOPICS'	=> 'Тем',
 	'TOPICS_UNAPPROVED' => 'Принаймні одну тему в цьому форумі не було схвалено.',
 	'TOPIC_ICON'	=> 'Значок теми',
 	'TOPIC_LOCKED'	=> 'Ця тема закрита, ви не можете редагувати повідомлення і писати відповіді',
