@@ -338,7 +338,7 @@ $help = array(
 	),
 	array(
 		0 => 'Чому на форумі немає функції X?',
-		1 => 'Це програмне забезпечення створено і ліцензовано phpBB Group. Якщо ви вважаєте, що необхідно додати якусь функцію, будь-ласка, відвідайте веб-сайт phpbb.com і перегляньте, яку думку відносно цього має phpBB Group. Будь-ласка, не розміщуйте запитів відносно нових функцій на форумі phpbb.com, phpBB Group використовує sourceforge для роботи над новими можливостями. Будь-ласка, спочатку перегляньте наші форуми, щоб дізнатись нашу думку на рахунок даної функції, і лише після цього дотримуйтесь процедури, яку вам буде надано.'
+		1 => 'Це програмне забезпечення створено і ліцензовано phpBB Group. Якщо ви вважаєте, що необхідно додати якусь функцію або хочете повідомити про помилку, будь-ласка, відвідайте веб-сайт phpBB <a href="http://area51.phpbb.com/">Area51</a>, там ви знайдете усі необхідні ресурси для цього.'
 	),
 	array(
 		0 => 'З ким мені зв\'язатись з питань некоректного використання і/або юридичних питань, пов\'язаних з цим форумом?',
