@@ -139,6 +139,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'	=> 'Поточне зображення',
 	'CURRENT_PASSWORD'	=> 'Поточний пароль',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'Вам необхідно ввести ваш поточний пароль, якщо ви бажаєте змінити ваше ім\'я користувача, адресу e-mail чи пароль.',
+  'CURRENT_CHANGE_PASSWORD_EXPLAIN' => 'Щоб змінити ваш пароль, адресу e-mail чи ім\'я користувача, ви повинні ввести ваш поточний пароль.',
 	'CUR_PASSWORD_EMPTY'		=> 'Ви не ввели свій поточний пароль.',
 	'CUR_PASSWORD_ERROR'	=> 'Пароль, введений вами, не співпадає з поточним паролем.',
 	'CUSTOM_DATEFORMAT'	=> 'Інший…',
@@ -368,6 +369,7 @@ $lang = array_merge($lang, array(
 	'RULE_ADDED'	=> 'Правило успішно додано',
 	'RULE_ALREADY_DEFINED'	=> 'Це правило було додано раніше',
 	'RULE_DELETED'	=> 'Правило успішно видалено',
+  'RULE_LIMIT_REACHED'				=> 'Ви не можете додавати більше правил. Ви досягли їхньої максимальної кількості.',
 	'RULE_NOT_DEFINED'	=> 'Правило вказане некоректно',
 	'RULE_REMOVED_MESSAGE'	=> 'Видалено 1 приватне повідомлення відповідно до встановлених фільтрів.',
 	'RULE_REMOVED_MESSAGES'	=> 'Видалено %d приватних повідомлень відповідно до встановлених фільтрів.',
